@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: EphyFind.h,v 1.7 2006/09/13 11:34:14 chpe Exp $
+ *  $Id: EphyFind.h 6916 2007-02-23 14:21:53Z chpe $
  */
 
 #ifndef TYPEAHEADFIND_H
@@ -44,7 +44,8 @@ class EphyFind
     void SetSelectionAttention (PRBool aAttention);
     EphyEmbedFindResult Find (const char *aSearchString,
 			      PRBool aLinksOnly);
-    EphyEmbedFindResult FindAgain (PRBool aForward);
+    EphyEmbedFindResult FindAgain (PRBool aForward,
+				   PRBool aLinksOnly);
     PRBool ActivateLink (GdkModifierType aMask);
 
   private:
@@ -54,7 +55,6 @@ class EphyFind
 
     nsCOMPtr<nsITypeAheadFind> mFinder;
     PRPackedBool mAttention;
-    PRPackedBool mHasFocus;
 };
 
 #endif /* !TYPEAHEADFIND_H */
