@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-file-chooser.c,v 1.24 2006/09/13 11:34:18 chpe Exp $
+ *  $Id: ephy-file-chooser.c 6740 2006-12-15 14:01:58Z chpe $
  */
 
 #include "config.h"
@@ -27,6 +27,7 @@
 #include "ephy-state.h"
 #include "ephy-gui.h"
 #include "ephy-debug.h"
+#include "ephy-stock-icons.h"
 
 #include <gtk/gtkstock.h>
 #include <libgnomevfs/gnome-vfs-utils.h>
@@ -116,7 +117,7 @@ ephy_file_chooser_constructor (GType type,
 		(GTK_FILE_CHOOSER (object), downloads_dir, NULL);
 	g_free (downloads_dir);
 
-	gtk_window_set_icon_name (GTK_WINDOW (object), "web-browser");
+	gtk_window_set_icon_name (GTK_WINDOW (object), EPHY_STOCK_EPHY);
 
 	return object;
 }
