@@ -1,6 +1,6 @@
 /*
- *  Copyright (C) 2003 Marco Pesenti Gritti
- *  Copyright (C) 2003, 2004 Christian Persch
+ *  Copyright © 2003 Marco Pesenti Gritti
+ *  Copyright © 2003, 2004 Christian Persch
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-shlib-loader.c,v 1.5 2005/01/28 22:24:03 chpe Exp $
+ *  $Id: ephy-shlib-loader.c 6588 2006-09-13 11:34:25Z chpe $
  */
 
 #include "config.h"
@@ -36,8 +36,6 @@ typedef struct
 	GObject *object;
 } LoaderData;
 
-static GQuark library_quark = 0;
-
 #define EPHY_SHLIB_LOADER_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE ((object), EPHY_TYPE_SHLIB_LOADER, EphyShlibLoaderPrivate))
 
 struct _EphyShlibLoaderPrivate
@@ -58,7 +56,7 @@ ephy_shlib_loader_get_type (void)
 
 	if (G_UNLIKELY (type == 0))
 	{
-		static const GTypeInfo our_info =
+		const GTypeInfo our_info =
 		{
 			sizeof (EphyShlibLoaderClass),
 			NULL, /* base_init */
@@ -71,7 +69,7 @@ ephy_shlib_loader_get_type (void)
 			(GInstanceInitFunc) ephy_shlib_loader_init
 		};
 
-		static const GInterfaceInfo loader_info =
+		const GInterfaceInfo loader_info =
 		{
 			(GInterfaceInitFunc) ephy_shlib_loader_iface_init,
 			NULL,
@@ -142,20 +140,25 @@ find_object (const LoaderData *data,
 
 static GObject *
 impl_get_object (EphyLoader *eloader,
-		 GData **attributes)
+		 GKeyFile *keyfile)
 {
 	EphyShlibLoader *loader = EPHY_SHLIB_LOADER (eloader);
 	GSList *l;
 	LoaderData *data = NULL;
-	const char *library;
+	char *library;
+	gboolean resident;
 
-	library = g_datalist_id_get_data (attributes, library_quark);
+	g_return_val_if_fail (keyfile != NULL, NULL);
+
+	library = g_key_file_get_string (keyfile, "Loader", "Library", NULL);
 	if (library == NULL)
 	{
 		g_warning ("NULL library name!\n");
 		return NULL;
 	}
 
+	resident = g_key_file_get_boolean (keyfile, "Loader", "Resident", NULL);
+
 	l = g_slist_find_custom (loader->priv->data, library,
 				(GCompareFunc) find_library);
 
@@ -166,6 +169,7 @@ impl_get_object (EphyLoader *eloader,
 
 		if (data->object != NULL)
 		{
+			g_free (library);
 			return g_object_ref (data->object);
 		}
 	}
@@ -177,13 +181,14 @@ impl_get_object (EphyLoader *eloader,
 
 	if (data->module == NULL)
 	{
-		data->module = ephy_module_new (library);
+		data->module = ephy_module_new (library, resident);
 	}
 
 	g_return_val_if_fail (data->object == NULL, data->object);
 
 	if (g_type_module_use (G_TYPE_MODULE (data->module)) == FALSE)
 	{
+		g_free (library);
 		g_warning ("Could not load extension file at %s\n",
 			   ephy_module_get_path (data->module));
 		return NULL;
@@ -198,6 +203,8 @@ impl_get_object (EphyLoader *eloader,
 		g_object_set_data (G_OBJECT (data->object), DATA_KEY, data);
 	}
 
+	g_free (library);
+
 	return data->object;
 }
 
@@ -236,6 +243,4 @@ ephy_shlib_loader_class_init (EphyShlibLoaderClass *klass)
 	object_class->finalize = ephy_shlib_loader_finalize;
 
 	g_type_class_add_private (object_class, sizeof (EphyShlibLoaderPrivate));
-
-	library_quark = g_quark_from_string ("library");
 }
