@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-stock-icons.h,v 1.26 2006/12/15 14:01:55 chpe Exp $
+ *  $Id: ephy-stock-icons.h 6830 2007-01-18 12:36:08Z lferrett $
  */
 
 #ifndef EPHY_STOCK_ICONS_H
@@ -27,21 +27,19 @@ G_BEGIN_DECLS
 
 #define EPHY_STOCK_POPUPS	   "popup-hidden"
 #define EPHY_STOCK_HISTORY         "history-view"
+#define EPHY_STOCK_BOOKMARK        "bookmark-web"
 #define EPHY_STOCK_BOOKMARKS       "bookmark-view"
 #define EPHY_STOCK_ENTRY	   "location-entry"
 #define EPHY_STOCK_DOWNLOAD	   "download"
 
 #define STOCK_NEW_TAB              "tab-new"
 #define STOCK_NEW_WINDOW           "window-new"
-#define STOCK_VIEW_SOURCE	   "text-html"
 #define STOCK_SEND_MAIL            "mail-forward"
 #define STOCK_ADD_BOOKMARK         "bookmark-new"
-#define STOCK_BOOKMARK             "stock_bookmark"
 #define STOCK_PRINT_SETUP          "stock_print-setup" /*document-page-setup*/
 #define STOCK_LOCK_INSECURE        "stock_lock-open"
 #define STOCK_LOCK_SECURE          "stock_lock"
 #define STOCK_LOCK_BROKEN	   "stock_lock-broken"
-#define STOCK_DRAG_MODE	   	   "stock_drag-mode"
 
 void ephy_stock_icons_init (void);
 
