@@ -1,8 +1,9 @@
+/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- *  Copyright (C) 2000-2003 Marco Pesenti Gritti
- *  Copyright (C) 2003, 2004, 2005 Christian Persch
- *  Copyright (C) 2004 Crispin Flowerday
- *  Copyright (C) 2004 Adam Hooper
+ *  Copyright © 2000-2003 Marco Pesenti Gritti
+ *  Copyright © 2003, 2004, 2005 Christian Persch
+ *  Copyright © 2004 Crispin Flowerday
+ *  Copyright © 2004 Adam Hooper
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -18,7 +19,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-tab.c,v 1.174 2006/04/25 11:40:41 chpe Exp $
+ *  $Id: ephy-tab.c 6810 2007-01-09 00:40:44Z diegoe $
  */
 
 #include "config.h"
@@ -189,7 +190,7 @@ ephy_tab_get_type (void)
 
         if (G_UNLIKELY (type == 0))
         {
-                static const GTypeInfo our_info =
+                const GTypeInfo our_info =
                 {
                         sizeof (EphyTabClass),
                         NULL, /* base_init */
@@ -201,7 +202,7 @@ ephy_tab_get_type (void)
                         0, /* n_preallocs */
                         (GInstanceInitFunc) ephy_tab_init
                 };
-		static const GInterfaceInfo link_info = 
+		const GInterfaceInfo link_info = 
 		{
 			NULL,
 			NULL,
@@ -628,7 +629,7 @@ ephy_tab_get_popups_allowed (EphyTab *tab)
 	g_return_val_if_fail (EPHY_IS_EMBED (embed), FALSE);
 
 	location = ephy_embed_get_location (embed, TRUE);
-	if (location == NULL) return FALSE; /* FALSE, TRUE... same thing */
+	if (location == NULL) return FALSE; /* FALSE, TRUE… same thing */
 
 	response = ephy_permission_manager_test_permission
 		(permission_manager, location, EPT_POPUP);
@@ -936,11 +937,11 @@ ephy_tab_set_loading_title (EphyTab *tab,
 	if (title != NULL && title[0] != '\0')
 	{
 		/* translators: %s here is the address of the web page */
-		priv->loading_title = g_strdup_printf (_("Loading “%s”..."), title);
+		priv->loading_title = g_strdup_printf (_("Loading “%s”…"), title);
 	}
 	else
 	{
-		priv->loading_title = g_strdup (_("Loading..."));
+		priv->loading_title = g_strdup (_("Loading…"));
 	}
 
 	g_free (freeme);
@@ -1616,7 +1617,6 @@ ephy_tab_zoom_changed_cb (EphyEmbed *embed, float zoom, EphyTab *tab)
 	{
 		EphyHistory *history;
 		EphyNode *host;
-		GValue value = { 0, };
 		history = EPHY_HISTORY
 			(ephy_embed_shell_get_global_history (embed_shell));
 		host = ephy_history_get_host (history, address);
@@ -1626,12 +1626,9 @@ ephy_tab_zoom_changed_cb (EphyEmbed *embed, float zoom, EphyTab *tab)
 			float zoom;
 
 			zoom = ephy_embed_get_zoom (embed);
-
-			g_value_init (&value, G_TYPE_FLOAT);
-			g_value_set_float (&value, zoom);
-			ephy_node_set_property
-				(host, EPHY_NODE_HOST_PROP_ZOOM, &value);
-			g_value_unset (&value);
+                        ephy_node_set_property_float (host,
+                                                      EPHY_NODE_HOST_PROP_ZOOM,
+                                                      zoom);
 		}
 	}
 
@@ -1695,15 +1692,15 @@ update_net_state_message (EphyTab *tab, const char *uri, EphyEmbedNetState flags
 	{
 		if (flags & EPHY_EMBED_STATE_REDIRECTING)
 		{
-			msg = _("Redirecting to “%s”...");
+			msg = _("Redirecting to “%s”…");
 		}
 		else if (flags & EPHY_EMBED_STATE_TRANSFERRING)
 		{
-			msg = _("Transferring data from “%s”...");
+			msg = _("Transferring data from “%s”…");
 		}
 		else if (flags & EPHY_EMBED_STATE_NEGOTIATING)
 		{
-			msg = _("Waiting for authorization from “%s”...");
+			msg = _("Waiting for authorization from “%s”…");
 		}
 	}
 
@@ -1711,7 +1708,7 @@ update_net_state_message (EphyTab *tab, const char *uri, EphyEmbedNetState flags
 	{
 		if (flags & EPHY_EMBED_STATE_START)
 		{
-			msg = _("Loading “%s”...");
+			msg = _("Loading “%s”…");
 		}
 	}
 
@@ -1905,7 +1902,7 @@ open_link_in_new (EphyTab *tab,
 	return FALSE;
 }
 
-static void
+static gboolean
 save_property_url (EphyEmbed *embed,
 		   EphyEmbedEvent *event,
 		   const char *property,
@@ -1918,6 +1915,8 @@ save_property_url (EphyEmbed *embed,
 	value = ephy_embed_event_get_property (event, property);
 	location = g_value_get_string (value);
 
+	if (!address_has_web_scheme (location)) return FALSE;
+
 	persist = EPHY_EMBED_PERSIST
 		(ephy_embed_factory_new_object (EPHY_TYPE_EMBED_PERSIST));
 
@@ -1929,6 +1928,8 @@ save_property_url (EphyEmbed *embed,
 	ephy_embed_persist_save (persist);
 
 	g_object_unref (G_OBJECT(persist));
+
+	return TRUE;
 }
 
 static void
@@ -2007,14 +2008,14 @@ ephy_tab_dom_mouse_click_cb (EphyEmbed *embed,
 	/* shift+click saves the link target */
 	else if (is_link && is_left_click && with_shift)
 	{
-		save_property_url (embed, event, "link", CONF_STATE_SAVE_DIR);
+		handled = save_property_url (embed, event, "link", CONF_STATE_SAVE_DIR);
 	}
 	/* shift+click saves the non-link image
 	 * Note: pressing enter to submit a form synthesizes a mouse click event
 	 */
 	else if (is_image && is_left_click && with_shift && !is_input)
 	{
-		save_property_url (embed, event, "image", CONF_STATE_SAVE_IMAGE_DIR);
+		handled = save_property_url (embed, event, "image", CONF_STATE_SAVE_IMAGE_DIR);
 	}
 	/* middle click opens the selection url */
 	else if (is_middle_clickable && is_middle_click && middle_click_opens)
@@ -2253,10 +2254,11 @@ ephy_tab_get_navigation_flags (EphyTab *tab)
  * ephy_tab_get_status_message:
  * @tab: an #EphyTab
  *
- * Returns the message displayed in @tab's #EphyWindow's #EphyStatusbar. If the
- * user is hovering the mouse over a hyperlink, this function will return the
- * same value as ephy_tab_get_link_message(). Otherwise, it will return a
- * network status message, or NULL.
+ * Returns the message displayed in @tab's #EphyWindow's
+ * #EphyStatusbar. If the user is hovering the mouse over a hyperlink,
+ * this function will return the same value as
+ * ephy_tab_get_link_message(). Otherwise, it will return a network
+ * status message, or NULL.
  *
  * The message returned has a limited lifetime, and so should be copied with
  * g_strdup() if it must be stored.
